.\" @(#)$RCSfile: lcg-get-checksum.man,v $ $Revision: 1.6 $ $Dat$ CERN Remi Mollon
.\" Copyright (C) 2009 by CERN
.\" All rights reserved
.\"
.TH "LCG-GET-CHECKSUM" "1" "$Date: 2009/11/19 13:58:41 $" "LCG_UTIL" "User Commands"

.SH "NAME"
lcg-get-checksum - Get/compute checksum value of given files

.SH "SYNOPSIS"
.B lcg-get-checksum
[
.B -h,--help
] [
.B --force
] [
.BI --checksum-type " cksmtype"
] [
.BI -D,--defaultsetype " defaulttype"
] [
.BI -T,--setype " setype"
] [
.BI -s,--se " se"
] [
.BI  --connect-timeout " conntimeout"
] [
.BI  --sendreceive-timeout " sndtimeout"
] [
.BI  --bdii-timeout " bdiitimeout"
] [
.BI  --srm-timeout " srmtimeout"
] [
.BI --vo " virtual_organization"
] [
.B -b,--nobdii
] [
.B -l,--nolfc
] [
.B -v,--verbose
] [
.B --version
] (
.BI -f,--file " localfile"
|
.I gridfile [...]
)

.SH "DESCRIPTION"
.B lcg-get-checksum
gets, or compute the checksum value of given files. If you specify a given command line option
multiple times, the command takes into account only the very last one so that in a script, you can
override a particular option in a pre-set option set (like gcc does).
.TP
.I gridfile
specifies a Logical File Name, a Grid Unique IDentifier or a Site URL.
An SURL scheme can be
.B sfn:
for a classical SE or
.BR srm: .
.TP
.I localfile
specifies a local file in which there is the list of SURLs.
.I cksmtype
is the checksum type (algorithm) to use. Possible values (case insensitive) are:
.RS
.TP 1.5i
.B CRC32
CRC32 algorithm will be used
.TP
.B ADLER32
Adler32 algorithm will be used (default value)
.TP
.B MD5
MD5 algorithm will be used
.TP
.B SHA1
SHA-1 algorithm will be used
.RE
.TP
.TP
.I se
Only the replica residing on
.I se
is deleted.
.TP
.I vo
specifies the Virtual Organization the user belongs to. If it is not specified,
the environment variable LCG_GFAL_VO will be used.
.TP
.I force
This option forces the computation of checksum value (gridftp for SURL, local computation for local files),
instead of getting it through
.I srmLs
when it is available.
Note that some SEs support checksum through
.I srmLs
only, so this option may make the command fail in this case.
.TP
.I conntimeout
Sets the connect timeout, used when connecting to a remote host. The connection will be aborted
if the remote host doesn't reply after
.I conntimeout
seconds. Default: 60 seconds.
.TP
.I sndtimeout
Sets the send/receive data timeout, used when transferring data to/from a remote host. The connection will be aborted
if no data is transfered after
.I sndtimeout
seconds. Default: 0 (blocking).
.TP
.I bdiitimeout
Sets the BDII timeout, used when searching information into BDII. The connection will be aborted
if the search is longer than
.I bdiitimeout
seconds. Default: 60 seconds.
.TP
.I srmtimeout
Sets the SRM timeout, used when doing an asynchronous SRM request. The request will be aborted
if it is still queued after
.I srmtimeout
seconds. Default: 3600 seconds (1 hour).
.TP
.I defaulttype
specifies the default SE type you want to use. Possible values are
.BR none ,
.BR se ,
.BR srmv1 ,
.BR srmv2 ,
for respectively no default type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will use another type.
.TP
.I setype
specifies the SE type you want to use for the file. Possible values are
.BR none ,
.BR se ,
.BR srmv1 ,
.BR srmv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.B -b,--nobdii
If this flag is present, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used.
.TP
.B -v,--verbose
Verbose mode. You can specify it twice for extra verbose mode.

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I --nobdii
option is used.

To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH "EXAMPLE"
.nf
.ft CW
	$ lcg-get-checksum --checksum-type md5 -bD srmv2 srm://lxb8002.cern.ch:8446/srm/managerv2?SFN=/dpm/cern.ch/home/dteam/remi.test
    3be0a491142e566d7f624624222c1518	srm://lxb8002.cern.ch:8446/srm/managerv2?SFN=/dpm/cern.ch/home/dteam/remi.test

	$ lcg-get-checksum file:/etc/issue
    c3581070	file:/etc/issue
.ft
.fi

.SH "EXIT STATUS"
This program returns 0 if the operation was successful or the number of files which failed.

.SH "SEE ALSO"
.BR lcg-aa (1),
.BR lcg-cp (1),
.BR lcg-cr (1),
.BR lcg-del (1),
.BR lcg-getturls (1),
.BR lcg-gt (1),
.BR lcg-la (1),
.BR lcg-lg (1),
.BR lcg-lr (1),
.BR lcg-ls (1),
.BR lcg-ra (1),
.BR lcg-rep (1),
.BR lcg-rf (1),
.BR lcg-sd (1),
.BR lcg-stmd (1),
.BR lcg-uf (1)
