.\" @(#)$RCSfile: lcg_get_checksum_python.man,v $ $Revision: 1.1 $ $Date: 2009/04/03 14:42:08 $ CERN Remi Mollon
.\" Copyright (C) 2009 by CERN
.\" All rights reserved
.\" 
.TH "LCG_GET_CHECKSUM" "3" "$Date: 2009/04/03 14:42:08 $" "LCG_UTIL" "Library Functions"

.SH "NAME"
lcg_get_checksum - Get/compute checksum value of given files

.SH "SYNOPSIS"
\fBimport lcg_util\fR
.sp
.BI "(int " returncode ,
.BI "listOfDict " checksums ,
.BI "string " errmsg
.BI ") lcg_util.lcg_get_checksum (listOfStrings " files ,
.BI "string " defaulttype ,
.BI "string " setype ,
.BI "int " nobdii ,
.BI "int " force ,
.BI "string " vo ,
.BI "enum gfal_cksm_type " cksmtype )

.SH "DESCRIPTION"
.B lcg_get_checksum
gets, or compute the checksum value of given files.
.TP 
.I nbfiles
specifies the number of elements in 
.BR files .
.TP
.I files
specifies a list of files of size 
.BR nbfiles .
.TP
.I defaulttype
specifies the default SE type you want to use. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no default type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will use another type.
.TP
.I setype
specifies the SE type you want to use for the source file. Possible values are
.BR TYPE_NONE ,
.BR TYPE_SE ,
.BR TYPE_SRM ,
.BR TYPE_SRMv2 ,
for respectively no type, classic SE, SRMv1, and SRMv2. But if according to the BDII the default type
is not available for this SE, it will fail.
.TP
.I nobdii
If set to a non-zero value, it means that you don't want to make BDII calls to get SE type. So, you must provide the type of the SE
for srm: arguments, and full endpoint in SURLs. For SE type,
.I defaulttype
can be used.
.TP
.I force
If set to a non-zero value, it means that the checksum value won't be obtained from
.I srmLs
function (even if available there). So the value is obtained either from gridftp, or it is computed (for local files).
Note that some SEs support checksum through 
.I srmLs
only, so this option may make the command fail in this case.
.TP
.I vo
specifies the Virtual Organization the user belongs to. If it is not specified,
the environment variable LCG_GFAL_VO will be used.
.TP 
.I cksmtype
is the checksum type (algorithm) to use. Possible values are:
.RS 
.TP 2.5i
.B GFAL_CKSM_NONE
default type will be used (Adler32)
.TP
.B GFAL_CKSM_CRC32
CRC32 algorithm will be used
.TP
.B GFAL_CKSM_ADLER32
Adler32 algorithm will be used
.TP
.B GFAL_CKSM_MD5
MD5 algorithm will be used
.TP
.B GFAL_CKSM_SHA1
SHA-1 algorithm will be used
.RE
.TP 
.I checksums
It is an out argument to show the status of each each file, with possibly an explanation.
So this is a pointer to a table of structures, which contains the following fields:
.RS
.RS
.TP 2i
.BI "char *" file
the file name 
.TP
.BI "int " status
the status of the file, which is a value of errno
.TP
.BI "char *" explanation
an explanation of this status (can be NULL)
.TP
.BI "char *" checksum
checksum value of the file, if available/computable.
.RE
.RE
.TP
.I errbuf
specifies a buffer of size
.I errbufsz
to receive detailed error messages. If this pointer is NULL, the message goes
to stderr. The pointer should not be NULL if the application is a daemon or is
multi\-threaded.

.SH "NOTE"
The environment variable LCG_GFAL_INFOSYS must point to the BDII, unless
.I nobdii
is set to a non-zero value.
To use the RLS as catalog instead of the LFC, the environment variable
LCG_CATALOG_TYPE must explicitely be set to "edg". By default, it is set to "lfc".

.SH "RETURN VALUE"
This routine returns 0 if the operation was successful or \-1 if the operation
failed. In the latter case,
.B errno
is set appropriately.

.SH "ERRORS"
.TP 1.3i
.B ENOENT
The named file does not exist.
.TP 
.B EACCES
Permission denied.
.TP 
.B EFAULT
.I file
or
.I vo
is an invalid pointer.
.TP 
.B ECOMM
Communication error.
.TP
.B ENAMETOOLONG
.I vo
is too long. 
.TP
.B EPROTONOSUPPORT
Access method not supported.

.SH "FILES"
.B /opt/lcg/include/lcg_util.h
.TP 
.B /opt/lcg/lib/liblcg_util.so

.SH "SEE ALSO"
.BR lcg_aa (3),
.BR lcg_cp (3),
.BR lcg_cr (3),
.BR lcg_del (3),
.BR lcg_gt (3),
.BR lcg_la (3),
.BR lcg_lg (3),
.BR lcg_lr (3),
.BR lcg_ra (3),
.BR lcg_rep (3),
.BR lcg_rf (3),
.BR lcg_sd (3),
.BR lcg_stmd (3),
.BR lcg_uf (3)
