#! /bin/bash

# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# These tests are independent. You can comment out any of them if you want to execute a 
# selected set only.

# Collection of test commands for Savannah bug #54872: 
#   lcg_util: should use -1 length for gridftp/CKSM
#
# https://savannah.cern.ch/bugs/?54872
#
# See test instructions there.

# DPM
#
# - upload a file. No checksum is calculated and stored in this case.
# - call srmLs, to verify that there is no checksum returned (as it is not stored).
# - call lcg-get-checksum to trigger checksum calculation and storing. It displays
#   the checksum.
# - call srmls again, it should display the checksum now, and must be equal to
#   the value in the previous point.
FILE="srm://vmgdda0013.cern.ch:8446/srm/managerv2?SFN=/dpm/cern.ch/home/dteam/a41.dat"
glite-url-copy -b -d -C file:///etc/redhat-release $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-get-checksum -bD srmv2 -v $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-del -lvbD srmv2 $FILE

# dCache
# After uploading the file, the checksum is calculated and stored.
#
# - upload a file. Checksum is calculated and stored.
# - call srmLs, it returns the checksum for the whole file.
# - call lcg-get-checksum. The checksum value should be the same like above.
FILE="srm://srm-devel.desy.de:8443/srm/managerv2?SFN=/pnfs/desy.de/data/dteam/a41.dat"
glite-url-copy -b -d -C file:///etc/redhat-release $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-get-checksum -bD srmv2 -v $FILE
lcg-del -lvbD srmv2 $FILE