/*
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Copyright (c) Members of the EGEE Collaboration. 2004.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <string.h>
#include "lcg_util.h"
#include "lcg_unit_testsuite.h"

/** Do not worry about the memory leaks in this sw :) (we free nothing) */
char * lcg_test__lcg_tokenize()
{
    char** res = NULL;
    /* NULL parameters should be handled properly */
    res = lcg_tokenize(NULL, NULL);
    LCG_TEST_ASSERT(res == NULL);
    res = lcg_tokenize(NULL, ",");
    LCG_TEST_ASSERT(res == NULL);
    res = lcg_tokenize("a,b", NULL);
    LCG_TEST_ASSERT(res == NULL);
    /* Test simple tokenizing */
    res = lcg_tokenize("a,b,c", ",");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a") == 0);
    LCG_TEST_ASSERT(strcmp(res[1], "b") == 0);
    LCG_TEST_ASSERT(strcmp(res[2], "c") == 0);
    LCG_TEST_ASSERT(res[3] == NULL);
    /* Test tokenizing with multiple separators */
    res = lcg_tokenize("a,b;c", ",;");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a") == 0);
    LCG_TEST_ASSERT(strcmp(res[1], "b") == 0);
    LCG_TEST_ASSERT(strcmp(res[2], "c") == 0);
    LCG_TEST_ASSERT(res[3] == NULL);
    /* Test tokenizing with empty string */
    res = lcg_tokenize("a,b;c", "");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a,b;c") == 0);
    LCG_TEST_ASSERT(res[1] == NULL);
    /* Test tokenizing of empty string */
    res = lcg_tokenize("", ",;");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(res[0] == NULL);
    /* Test the not existing separator case */
    res = lcg_tokenize("a,b;c", "=");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a,b;c") == 0);
    LCG_TEST_ASSERT(res[1] == NULL);
    return NULL;
}
